hasher

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 5, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Must

func Must[T any](t T, err error) T

Types

type Hasher

type Hasher[T any] func(io.Reader) (T, error)

Hasher defines functions that can be used to produce hash This functions works with io.Reader for maximum versatility, for simpler cases like working with strings or bytes utility package hash can be used.

Example: hash.String(sha256.SHA256, "Hello, world")

Directories

Path Synopsis

Jump to